rm(list=ls())
library(foreign)
library(MASS)
library(survival)
library(simPH)
#library(Cairo)


#Load Dataset
dat <- read.dta("3 - EP reelection.dta")
  

#########Replicate Table 1 Analysis##########

######Basic Model
mod.1 <- coxph(Surv(durat, fail) ~ fed_deJure + age + EP_leader + leadership + farLeft + female, data = dat, method = "breslow")
summary(mod.1)




#########Survival Curves and Cumulative Hazards ##########

####Scenarios with Federal and Non-Federal Home Systems, all else at median
sit.nofed <- data.frame(fed_deJure = 0, age = median(dat$age, na.rm=TRUE), EP_leader = median(dat$EP_leader, na.rm=TRUE), leadership = median(dat$leadership, na.rm=TRUE), farLeft = median(dat$farLeft, na.rm=TRUE), female = median(dat$female, na.rm=TRUE))
sit.fed <- data.frame(fed_deJure = 1, age = median(dat$age, na.rm=TRUE), EP_leader = median(dat$EP_leader, na.rm=TRUE), leadership = median(dat$leadership, na.rm=TRUE), farLeft = median(dat$farLeft, na.rm=TRUE), female = median(dat$female, na.rm=TRUE))

fit.nofed <- survfit(mod.1, newdata=sit.nofed)
fit.fed <- survfit(mod.1, newdata=sit.fed)


dev.new(width=5.5, height=5.5)
pdf("Fig_Surv_ci.pdf", 6, 6,  bg="transparent")
plot(c(0,7), c(0,1),xlab="Number of Terms", ylab="Probability MEP Leaves Office", type="n", main="")
lines(fit.fed, lty=1, col="red")
lines(fit.nofed, lty=1)

legend("topright", c("MEP from Federal Country","MEP from Non-Federal Country"), lty=c(1,1), col=c("red", "black") ,bty="n")
dev.off()

dev.new(width=5.5, height=5.5)
pdf("Fig_CumHaz_ci.pdf", 6, 6,  bg="transparent")
plot(c(0,7), c(0,5),xlab="Number of Terms", ylab="Cumulative Hazard of MEP Turnover", type="n", main="")
lines(fit.fed, lty=1, fun = "cumhaz", col="red")
lines(fit.nofed, lty=1, fun = "cumhaz")

legend("topleft", c("MEP from Federal Country","MEP from Non-Federal Country"), lty=c(1,1), col=c("red", "black") ,bty="n")

dev.off()



####SIMPH Functions

#median center the AGE variable so it centers around 0
dat$age <- dat$age - median(dat$age, na.rm=TRUE)

summary(dat$age)

set.seed(2684)
rel.haz.sim <- coxsimLinear(mod.1, b = "age", Xj = seq(-32, 35, by = .05))
dev.new(width=5.5, height=5.5)
pdf("Fig_RelHazSim.pdf", 6, 6,  bg="transparent")
simGG(rel.haz.sim, xlab = "Age, Relative to Median", ylab = "Relative Hazard with Comparison to \nMedian Age", type = "lines")
dev.off()

